@@ -19,11 +19,11 @@ import sys
 from github import Github
 
 
-from commands import auth
-from commands import selectrepo
-from commands import allrepo
+import auth
+import selectrepo
+import allrepo
 # from commands import reset
-from commands import webhook
+import webhook
 
 
 @click.group(help="CLI tool to manage full development cycle of projects")
